<template>
  <div ref="dataMap" style="width: 100%; height: 100%"></div>
</template>

<script>
import henan from './henan.json';
import echarts from 'echarts';
import dataVRequest from '@/api/dataV.js';

echarts.registerMap('河南', henan); //加载json数据，并注册到echars中
export default {
  name: 'data-map',
  async mounted() {
    const myChart5 = echarts.init(this.$refs.dataMap);
    const resData = await dataVRequest.queryProjectMap();
    console.log('resData',resData);
    const option = {
      backgroundColor: 'rgba(21, 21, 21, 0.2)', //地图背景色
      //显示悬浮窗口--标签
      tooltip: {
        trigger: 'item',
        confine: true,
        backgroundColor: 'rgba(21, 21, 21, 0.82)', //标签背景色
        borderColor: '#FFFFCC',
        showDelay: 0,
        hideDelay: 0,
        enterable: true, //鼠标是否可进入提示框浮层中，默认为false，如需详情内交互，如添加链接，按钮，可设置为 true
        transitionDuration: 0, //提示框浮层的移动动画过渡时间，单位是 s，设置为 0 的时候会紧跟着鼠标移动
        extraCssText: 'z-index:100;', //修改标签大小样式等
        //   点击事件，点击圆点，跳转
        formatter: function (params, ticket, callback) {
          //根据业务自己拓展要显示的内容
          // ing:进行中
          // wait:未开工
          // name: 城市名;
          // end: 已完工;
          // close: 已关闭
          // expired: 已超期
          // planMoney: 计划总投资
          // payMoney: 已下达投资
          let res = '';
          res = `
            <div style="position: absolute;top: 0;left: 0;background-color: rgba(17, 66, 138,0.7);z-index: 1000;width: 150px; padding: 8px; border: 1px solid #A5EBFF;color: #fff;">
              <div style="font-size: 16px;font-weight: bold;line-height: 20px;margin-bottom: 8px;">${params.name}</div>
              <div style="display: flex;justify-content: space-between;align-items: center;">
                <p style="font-size: 12px;">进行中</p>
                <p style="font-size: 16px;">${params.value}个</p>
              </div>
              <div style="display: flex;justify-content: space-between;align-items: center;">
                <p style="font-size: 12px;">未开工</p>
                <p style="font-size: 16px;">${params.data.ywtd}个</p>
              </div>
              <div style="display: flex;justify-content: space-between;align-items: center;">
                <p style="font-size: 12px;">已完工</p>
                <p style="font-size: 16px;">416个</p>
              </div>
              <div style="display: flex;justify-content: space-between;align-items: center;">
                <p style="font-size: 12px;">已关闭</p>
                <p style="font-size: 16px;">416个</p>
              </div>
              <div style="display: flex;justify-content: space-between;align-items: center;">
                <p style="font-size: 12px;">已超期</p>
                <p style="font-size: 16px;">416个</p>
              </div>
              <div style="display: flex;justify-content: space-between;align-items: center;">
                <p style="font-size: 12px;">计划总投资</p>
                <p style="font-size: 16px;">416万</p>
              </div>
              <div style="display: flex;justify-content: space-between;align-items: center;">
                <p style="font-size: 12px;">已下达投资</p>
                <p style="font-size: 16px;">416万</p>
              </div>
            </div>`;
          return res;
        },
      },
      geo: {
        map: '河南', // 可选 china  world  省份（河南省）
        // 关于map的值：中国、世界地图是英文，省份是中文。比如 ‘china’ ，'浙江’等，若填写'zhejiang'是找不到的。引用之前可以查看一下js文件啦。一定要引对
        zoom: 1.2, //
        //   center: [113.625351,34.746303, 10],//坐标定位和left top  bottom  right冲突，使用一个就可以啦
        left: 'center', //左右居中
        top: 'middle', //水平居中
        label: {
          //  是否显示市区名字
          normal: {
            show: true,
            color: '#fff',
            fontSize: 16,
          },
          //   hover高亮的时候显示市区名字
          emphasis: {
            show: true, //地图中名称的显示与否
            color: '#fff',
          },
        },
        roam: true, //是否允许缩放
        scaleLimit: {
          //所属组件的z分层，z值小的图形会被z值大的图形覆盖
          min: 1, //最小的缩放值
          max: 40, //最大的缩放值
        },
        //   地图外观定制
        itemStyle: {
          //   正常显示的样式
          normal: {
            shadowColor: 'rgba(0, 0, 0, 0.5)',
            shadowBlur: 10,
            shadowOffsetX: -5,
            shadowOffsetY: -5,
            areaColor: {
              type: 'linear',
              x: 1,
              y: 0,
              x2: 0.5,
              y2: 1,
              colorStops: [
                {
                  offset: 0,
                  color: '#5E9BBE', // 0% 处的颜色
                },
                {
                  offset: 1,
                  color: '#2972D6', // 100% 处的颜色
                },
              ],
              global: false, // 缺省为 false
            },
            borderColor: '#8ACFEE', //省市边界线00fcff 516a89
            borderWidth: 1,
          },
          // 鼠标悬浮下样式
          emphasis: {
            areaColor: {
              type: 'linear',
              x: 1,
              y: 0,
              x2: 0.5,
              y2: 1,
              colorStops: [
                {
                  offset: 0,
                  color: '#F9D746', // 0% 处的颜色
                },
                {
                  offset: 1,
                  color: '#D88B10', // 100% 处的颜色
                },
              ],
              global: false, // 缺省为 false
            },
          },
        },
      },
      series: [
        // 配置数据的显示
        {
          type: 'map', // 类型map
          map: '河南',
          label: {
            show: true,
          },
          geoIndex: 0, // 指定geo属性后，series-map.map 属性，以及 series-map.itemStyle 等样式配置不再起作用，而是采用 geo 中的相应属性。
          data: [
            {
              name: '郑州市',
              value: 123344,
              ywtd: 998,
              gdzs: 9802,
              jxz: 863,
              zsk: 233,
            },
            {
              name: '焦作市',
              value: 123344,
              ywtd: 998,
              gdzs: 9802,
              jxz: 863,
              zsk: 233,
            },
            {
              name: '新乡市',
              value: 123344,
              ywtd: 998,
              gdzs: 9802,
              jxz: 863,
              zsk: 233,
            },
            {
              name: '商丘市',
              value: 123344,
              ywtd: 998,
              gdzs: 9802,
              jxz: 863,
              zsk: 233,
            },
            {
              name: '信阳市',
              value: 123344,
              ywtd: 998,
              gdzs: 9802,
              jxz: 863,
              zsk: 233,
            },
            {
              name: '周口市',
              value: 123344,
              ywtd: 998,
              gdzs: 9802,
              jxz: 863,
              zsk: 233,
            },
            {
              name: '开封市',
              value: 123344,
              ywtd: 998,
              gdzs: 9802,
              jxz: 863,
              zsk: 233,
            },
            {
              name: '驻马店市',
              value: 123344,
              ywtd: 998,
              gdzs: 9802,
              jxz: 863,
              zsk: 233,
            },
            {
              name: '南阳市',
              value: 123344,
              ywtd: 998,
              gdzs: 9802,
              jxz: 863,
              zsk: 233,
            },
            {
              name: '许昌市',
              value: 123344,
              ywtd: 998,
              gdzs: 9802,
              jxz: 863,
              zsk: 233,
            },
            {
              name: '漯河市',
              value: 123344,
              ywtd: 998,
              gdzs: 9802,
              jxz: 863,
              zsk: 233,
            },
            {
              name: '平顶山市',
              value: 123344,
              ywtd: 998,
              gdzs: 9802,
              jxz: 863,
              zsk: 233,
            },
            {
              name: '安阳市',
              value: 123344,
              ywtd: 998,
              gdzs: 9802,
              jxz: 863,
              zsk: 233,
            },
            {
              name: '鹤壁市',
              value: 123344,
              ywtd: 998,
              gdzs: 9802,
              jxz: 863,
              zsk: 233,
            },
            {
              name: '濮阳市',
              value: 123344,
              ywtd: 998,
              gdzs: 9802,
              jxz: 863,
              zsk: 233,
            },
            {
              name: '济源市',
              value: 123344,
              ywtd: 998,
              gdzs: 9802,
              jxz: 863,
              zsk: 233,
            },
            {
              name: '洛阳市',
              value: 123344,
              ywtd: 998,
              gdzs: 9802,
              jxz: 863,
              zsk: 233,
            },
            {
              name: '三门峡市',
              value: 123344,
              ywtd: 998,
              gdzs: 9802,
              jxz: 863,
              zsk: 233,
            },
          ],
        },
      ],
    };
    option && myChart5.setOption(option);
  },
};
</script>

<style scoped></style>
